Cypress.Commands.addQuery('findShadowInput', function () {
    const getShadow = cy.now('shadow');
    const getInput = cy.now('find', 'input');
    return (subject) => {
        if (!subject?.[0].tagName.startsWith('UI5')) {
            const err = `findShadowInput() needs to be chained to a ui5-webcomponent`;
            throw new TypeError(err);
        }
        // @ts-expect-error: recommended approach per cypress docs
        const shadow = getShadow(subject);
        // @ts-expect-error: recommended approach per cypress docs
        return getInput(shadow);
    };
});
Cypress.Commands.addQuery('findUi5TabByText', function (text) {
    const getTabList = cy.now('find', '[role="tablist"]');
    const getText = cy.now('contains', text);
    const getParent = cy.now('parents', '[role="tab"]');
    return (subject) => {
        if (!subject?.[0]?.hasAttribute('ui5-tabcontainer')) {
            const err = `findUi5TabByText() needs to be chained to a \`ui5-tabcontainer\``;
            throw new TypeError(err);
        }
        // @ts-expect-error: recommended approach per cypress docs
        const tabList = getTabList(subject);
        // @ts-expect-error: recommended approach per cypress docs
        const text = getText(tabList);
        // @ts-expect-error: recommended approach per cypress docs
        const parent = getParent(text);
        return parent;
    };
});
Cypress.Commands.addQuery('findUi5TabOpenPopoverButtonByText', function (text) {
    const getTabList = cy.now('find', '[role="tablist"]');
    const getText = cy.now('contains', text);
    const getParent = cy.now('parents', '[role="tab"]');
    const getButton = cy.now('find', '[ui5-button]');
    return (subject) => {
        if (!subject?.[0]?.hasAttribute('ui5-tabcontainer')) {
            const err = `findUi5TabOpenPopoverButtonByText() needs to be chained to a \`ui5-tabcontainer\``;
            throw new TypeError(err);
        }
        // @ts-expect-error: recommended approach per cypress docs
        const tabList = getTabList(subject);
        // @ts-expect-error: recommended approach per cypress docs
        const text = getText(tabList);
        // @ts-expect-error: recommended approach per cypress docs
        const parent = getParent(text);
        // @ts-expect-error: recommended approach per cypress docs
        const button = getButton(parent);
        return button;
    };
});
export {};
